/*******************************************************************************

	Project:		CASCADE 
	Institution:	CATIE / CI
 
	Author:			Tabare Capitan 
				
	Contact:		tcapitan@catie.ac.cr

	Description:	Create daily reports
				
	Input:			primary.dta
 
	Output:			reporte_duracion_[DATE].xslx
					reporte_cuadrantes_[DATE].xslx
					reporte_encuestas_[DATE].xslx
 
*******************************************************************************/
version 13
clear
 
cd "$RUTA\Honduras\Yoro\Datos\"
 
 
*** DURATION REPORT ************************************************************
 
use primary, clear
 
keep if nuevas == 1
 
by enumerator, sort: egen duracion_prom = mean(duracion_m) 

gen contador = 1

collapse duracion_m (min)duracion_min=duracion_m (max)duracion_max=duracion_m (sum) encuestas=contador, by(enumerator)

sort enumerator
 
local fecha_actual = c(current_date) 
 
export excel using "$RUTA\Honduras\Yoro\Reportes\reporte_duracion_`fecha_actual'", replace firstrow(var)
 	
	
*** REPORT BY QUADRANT *********************************************************

use primary, clear
 
keep if nuevas == 1
 
by cuadrante, sort: egen duracion_prom = mean(duracion_m) 

gen contador = 1

collapse duracion_m (min)duracion_min=duracion_m (max)duracion_max=duracion_m (sum) encuestas=contador, by(cuadrante)

sort cuadrante
 
local fecha_actual = c(current_date)
  
export excel using "$RUTA\Honduras\Yoro\Reportes\reporte_cuadrantes_`fecha_actual'", replace firstrow(var)
 
 
*** REPORT BY INDIVIDUAL FORM **************************************************
	 
use primary, clear
 
keep if nuevas == 1
 
gen tiene_gps = ( gps_coordinateslatitude != . )
	 
keep enumerator n_survey tiene_gps n_techo n_techo_reemplazo coffee maize beans cuadrante starttime endtime duracion_m post05 post06 post07 post08 post09 post10 nuevas

drop nuevas
	 
order enumerator n_survey cuadrante n_techo n_techo_reemplazo duracion_m coffee maize beans post05 post06 post07 post08 post09 post10 tiene_gps starttime endtime 
 
sort enumerator
	 
rename post05 interrupcion
	 
rename post06 interrupcion_duracion
	 
rename post07 motivo_interrupcion
	 
rename post08 otra_persona_presente
	 
rename post09 otra_persona_participo
	 
rename post10 calidad
	 
local fecha_actual = c(current_date)
  	 
export excel using "$RUTA\Honduras\Yoro\Reportes\reporte_encuestas_`fecha_actual'", replace firstrow(var)
	 
*** END OF FILE ****************************************************************
