/*******************************************************************************

	Project:		CASCADE 
	Institution:	CATIE / CI
 
	Author:			Tabare Capitan (portions of the code were adapted from 
					SurveyCTO's	stata-templates)
				
	Contact:		tcapitan@catie.ac.cr

	Description:	1. Create a dta from the original .csv 
					2. Create back-up files
				
	Input:			Honduras - Yoro_1.csv
					Honduras - Yoro_1-filter_approved-group005-repeat009.csv
					Honduras - Yoro_1-filter_approved-group005-repeat010.csv
					Honduras - Yoro_1-filter_approved-group008-repeat001.csv
					Honduras - Yoro_1-filter_approved-group008-repeat002.csv
					Honduras - Yoro_1-filter_approved-group014-repeat003.csv
					Honduras - Yoro_1-filter_approved-group014-repeat004.csv
					Honduras - Yoro_1-filter_approved-group729-repeat013.csv
 
	Output:			primary.dta
					back up files
 
*******************************************************************************/
version 13
clear

*** LOCAL MACROS ***************************************************************
local csvfile "$RUTA\Honduras\Yoro\Datos\Honduras - Yoro_1.csv"
local dtafile "$RUTA\Honduras\Yoroa\Datos\Honduras - Yoro_1.dta"

local csvfile009 "$RUTA\Honduras\Yoro\Datos\Honduras - Yoro_1-filter_approved-group005-repeat009.csv"
local csvfile010 "$RUTA\Honduras\Yoro\Datos\Honduras - Yoro_1-filter_approved-group005-repeat010.csv"
local csvfile001 "$RUTA\Honduras\Yoro\Datos\Honduras - Yoro_1-filter_approved-group008-repeat001.csv"
local csvfile002 "$RUTA\Honduras\Yoro\Datos\Honduras - Yoro_1-filter_approved-group008-repeat002.csv"
local csvfile003 "$RUTA\Honduras\Yoro\Datos\Honduras - Yoro_1-filter_approved-group014-repeat003.csv"
local csvfile004 "$RUTA\Honduras\Yoro\Datos\Honduras - Yoro_1-filter_approved-group014-repeat004.csv"
local csvfile013 "$RUTA\Honduras\Yoro\Datos\Honduras - Yoro_1-filter_approved-group729-repeat013.csv"

local date_fields1 ""
local datetime_fields1 "starttime endtime"


*** IMPORT DATA ****************************************************************
insheet using "`csvfile'", names clear 


*** DROP NOTE FIELDS ***********************************************************
capture drop note* 


*** FORMAT DATE AND TIME FIELDS ************************************************
forvalues i = 1/100 {
	if "`datetime_fields`i''" ~= "" {
		foreach dtvarlist in `datetime_fields`i'' {
			foreach dtvar of varlist `dtvarlist' {
				tempvar tempdtvar
				rename `dtvar' `tempdtvar'
				gen double `dtvar'=.
				cap replace `dtvar'=clock(`tempdtvar',"MDYhms",2025)
				* automatically try without seconds, just in case
				cap replace `dtvar'=clock(`tempdtvar',"MDYhm",2025) if `dtvar'==. & `tempdtvar'~=""
				format %tc `dtvar'
				drop `tempdtvar'
			}
		}
	}
	if "`date_fields`i''" ~= "" {
		foreach dtvarlist in `date_fields`i'' {
			foreach dtvar of varlist `dtvarlist' {
				tempvar tempdtvar
				rename `dtvar' `tempdtvar'
				gen double `dtvar'=.
				cap replace `dtvar'=date(`tempdtvar',"MDY",2025)
				format %td `dtvar'
				drop `tempdtvar'
			}
		}
	}
}


*** GENERATE VARIABLES FOR THE REPORTS *****************************************

* Generate a variable withT the date
gen date = dofc(starttime)
format date %td
	
* Generate a variable with duration
gen double duration = endtime - starttime
format duration %tc
	
gen hours = hh(duration)
gen minutes = mm(duration)
gen  duracion_m = hours * 60 + minutes
	
	
*** IDENTIFY NEW OBSERVATIONS **************************************************

gen dia_actual = day(date) 
	
gen nuevas = ( dia_actual == 12 ) 		// -----------------------------------------> CHANGE IT!

	
*** SAVE DTA *******************************************************************
save "$RUTA\Honduras\Yoro\Datos\primary", replace


*** BACK-UPS *******************************************************************

* main
local fecha_actual = c(current_date)
outsheet using "$RUTA\Honduras\Yoro\Respaldo\HN_Yoro_1_`fecha_actual'.csv", replace names comma
clear
* 009
insheet using "`csvfile009'", names clear 
local fecha_actual = c(current_date)
outsheet using "$RUTA\Honduras\Yoro\Respaldo\HN_Yoro_1_009_`fecha_actual'.csv", replace names comma
clear	
* 010
insheet using "`csvfile009'", names clear 
local fecha_actual = c(current_date)
outsheet using "$RUTA\Honduras\Yoro\Respaldo\HN_Yoro_1_010_`fecha_actual'.csv", replace names comma
clear		
* 001
insheet using "`csvfile009'", names clear 
local fecha_actual = c(current_date)
outsheet using "$RUTA\Honduras\Yoro\Respaldo\HN_Yoro_1_001_`fecha_actual'.csv", replace names comma
clear	
* 002
insheet using "`csvfile009'", names clear 
local fecha_actual = c(current_date)
outsheet using "$RUTA\Honduras\Yoro\Respaldo\HN_Yoro_1_002_`fecha_actual'.csv", replace names comma
clear	
* 003
insheet using "`csvfile009'", names clear 
local fecha_actual = c(current_date)
outsheet using "$RUTA\Honduras\Yoro\Respaldo\HN_Yoro_1_003_`fecha_actual'.csv", replace names comma
clear	
* 004
insheet using "`csvfile009'", names clear 
local fecha_actual = c(current_date)
outsheet using "$RUTA\Honduras\Yoro\Respaldo\HN_Yoro_1_004_`fecha_actual'.csv", replace names comma
clear	
* 013
insheet using "`csvfile009'", names clear 
local fecha_actual = c(current_date)
outsheet using "$RUTA\Honduras\Yoro\Respaldo\HN_Yoro_1_013_`fecha_actual'.csv", replace names comma
clear	
								
*** END OF FILE ****************************************************************	


